@@ -24,7 +24,7 @@ import time
 from typing import Union as _Union
 from typing import Iterable as _Iterable
 import sqlite3
-import mysql.connector
+import mysql.connector as _mysqlConnnector
 import traceback as _traceback
 from mysql.connector import Error
 from colorama import Fore as _Fore
@@ -360,7 +360,7 @@ class DatabaseManager:
             self.con = None
             try:
 
-                self.con = mysql.connector.connect(
+                self.con = _mysqlConnnector.connect(
                     user=self.data['db_credentials']['user'],
                     password=self.data['db_credentials']['password'],
                     host=self.data['db_credentials']['host'],
@@ -1508,11 +1508,11 @@ class DatabaseManager:
             success = True
 
 
-        except mysql.connector.errors.IntegrityError:
+        except _mysqlConnnector.errors.IntegrityError:
             _log(f"{_traceback.format_exc()}","error")
             _log(f"SQL: {sql}","error")
 
-        except mysql.connector.errors.InterfaceError:
+        except _mysqlConnnector.errors.InterfaceError:
             if isTimeoutRetry is True:
                 _log(f"{_traceback.format_exc()}","error")
                 _log(f"SQL: {sql}","error")
@@ -1523,7 +1523,7 @@ class DatabaseManager:
                 self.connect()
                 return self.execute_single_statement(sql,args,True)
 
-        except mysql.connector.errors.DatabaseError:
+        except _mysqlConnnector.errors.DatabaseError:
             # print(f"ERROR: {err}", PRESET="FATAL_ERROR_INVERT")
             _log(f"{_traceback.format_exc()}","error")
             _log(f"SQL: {sql}","error")
